@@ -1,13 +1,13 @@
 package Net::DNS::RR::TSIG;
 
 #
-# $Id: TSIG.pm 1508 2016-09-29 12:58:11Z willem $
+# $Id: TSIG.pm 1597 2017-09-22 08:04:02Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1508 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
@@ -43,27 +43,19 @@ use constant TSIG => typebyname qw(TSIG);
 		'HMAC-SHA512'		   => 165,
 		);
 
-	my @algbyalias = (
+	my @algalias = (
 		'HMAC-MD5' => 157,
 		'HMAC-SHA' => 161,
 		);
 
-
 	my %algbyval = reverse @algbyname;
 
-	my $map = sub {
-		my $arg = shift;
-		return $arg if $arg =~ /^\d/;
-		$arg =~ s/[^A-Za-z0-9]//g;			# strip non-alphanumerics
-		uc($arg);
-	};
-
-	my @pairedval = sort ( 1 .. 254, 1 .. 254 );		# also accept number
-	my %algbyname = map &$map($_), @algbyalias, @algbyname, @pairedval;
+	my @algrehash = map /^\d/ ? ($_) x 3 : do { s/[\W_]//g; uc($_) }, @algbyname, @algalias;
+	my %algbyname = @algrehash;				# work around broken cperl
 
 	sub _algbyname {
 		my $key = uc shift;				# synthetic key
-		$key =~ s/[^A-Z0-9]//g;				# strip non-alphanumerics
+		$key =~ s/[\W_]//g;				# strip non-alphanumerics
 		$algbyname{$key};
 	}
 
@@ -229,9 +221,8 @@ sub macbin {
 
 sub prior_mac {
 	my $self = shift;
-
-	$self->prior_macbin( pack "H*", map { die "!hex!" if m/[^0-9A-Fa-f]/; $_ } join "", @_ ) if scalar @_;
-	unpack "H*", $self->prior_macbin() if defined wantarray;
+	return unpack "H*", $self->prior_macbin() unless scalar @_;
+	$self->prior_macbin( pack "H*", map /[^\dA-F]/i ? croak "corrupt hex" : $_, join "", @_ );
 }
 
 
@@ -245,9 +236,8 @@ sub prior_macbin {
 
 sub request_mac {
 	my $self = shift;
-
-	$self->request_macbin( pack "H*", map { die "!hex!" if m/[^0-9A-Fa-f]/; $_ } join "", @_ ) if scalar @_;
-	unpack "H*", $self->request_macbin() if defined wantarray;
+	return unpack "H*", $self->request_macbin() unless scalar @_;
+	$self->request_macbin( pack "H*", map /[^\dA-F]/i ? croak "corrupt hex" : $_, join "", @_ );
 }
 
 
@@ -282,7 +272,7 @@ sub other {
 }
 
 
-sub other_data {&other}						# uncoverable pod
+sub other_data { &other; }					# uncoverable pod
 
 
 sub sig_function {
@@ -387,21 +377,19 @@ sub create {
 			key  => $key
 			);
 
-	} elsif ( $karg =~ /[+.0-9]+private$/ ) {		# ( keyfile, options )
+	} elsif ( $karg =~ /private$/ ) {			# ( keyfile, options )
 		require File::Spec;
 		require Net::DNS::ZoneFile;
 		my $keyfile = new Net::DNS::ZoneFile($karg);
 		my ( $alg, $key, $junk );
-		while ( my $line = $keyfile->_getline ) {
-			for ($line) {
-				( $junk, $alg ) = split if /Algorithm:/;
-				( $junk, $key ) = split if /Key:/;
-			}
+		while ( $keyfile->_getline ) {
+			( $junk, $alg ) = split if /Algorithm:/;
+			( $junk, $key ) = split if /Key:/;
 		}
 
 		my ( $vol, $dir, $file ) = File::Spec->splitpath( $keyfile->name );
-		my $kname;
-		$kname = $1 if $file =~ /^K([^+]+)+.+private$/;
+		croak "misnamed private key" unless $file =~ /^K([^+]+)+.+private$/;
+		my $kname = $1;
 		return new Net::DNS::RR(
 			name	  => $kname,
 			type	  => 'TSIG',
@@ -533,7 +521,7 @@ sub vrfyerrstr {
 		my $private = shift;	# closure keeps private key private
 		$keyref->{key} = sub {
 			my $function = $keyref->{digest};
-			return &$function( $private, shift );
+			return &$function( $private, @_ );
 		};
 		return undef;
 	}
@@ -547,7 +535,7 @@ sub vrfyerrstr {
 		my $keyref = $keytable{$owner};
 		$keyref->{digest} = $self->sig_function unless $keyref->{digest};
 		my $function = $keyref->{key};
-		&$function(shift);
+		&$function(@_);
 	}
 }
 
